@@ -2,7 +2,10 @@ from pathlib import Path
 
 from django.conf import settings
 
-DEFAULT_ENTRY_OPEN_READ_TIMEOUT = 2
+AUTODETECT_CHANNEL_ENTRIES_MAX = 5
+AUTODETECT_RESULTS_EXPIRE_TIME = 3600
+DEFAULT_MARK_AS_READ_RATIO = 1
+DEFAULT_MARK_AS_READ_OPEN_TIME = 2
 DEFAULT_UPDATE_FREQUENCY = 3600
 FETCHERS_CACHE_DIR: Path = settings.BASE_DIR / "cache"
 FEED_FETCHER_LOCAL_FEEDS_DIR: Path = settings.BASE_DIR / "feeds"
